@@ -3,16 +3,23 @@ import json
 import logging
 
 
-def export_list_of_dicts_to_file(data, file_path):
-    """Exports the data to a file.
+def export_to_json(data, file_path):
+    """Exports the data to a json file.
 
     Args:
         data (list[dict]): The data to be exported.
         file_path (str): The path to save the file.
     """
+    # check if the file path ends with .json
+    if not file_path.endswith(".json"):
+        logging.info("Adding .json to the file path...")
+        file_path += ".json"  # add .json to the file path
+
+    # write the data to a json file
     with open(file_path, "w") as file:
-        for item in data:
-            file.write(f"{json.dumps(item)}\n")
+        logging.info(f"Exporting data to {file_path}...")
+        json.dump(data, file, indent=4)
+        logging.info("Data exported successfully.")
 
 
 def initialize_logger(file_handler_path=None):
@@ -80,12 +87,54 @@ def parse_to_nldjson(data_to_parse, upload_date=True):
 
     # convert to newline delimited json
     if upload_date:  # add upload date to the payload
+        logging.info("Adding upload date and converting data to nldjson...")
         for item in data_to_parse:
             item["upload_date"] = datetime.date.today().isoformat()
             nld_json += f"{json.dumps(item)}\n"
 
     else:  # upload date is not required
+        logging.info("Converting data to nldjson...")
         for item in data_to_parse:
             nld_json += f"{json.dumps(item)}\n"
 
     return nld_json
+
+
+def replace_periods_in_keys(data):
+    """Recursively replaces periods in the keys of the given data dict or list of dicts with underscores.
+
+    Args:
+        data (dict, list[dict]): The data to convert.
+
+    Returns:
+        dict, list[dict]: The data with periods replaced by underscores in the keys.
+
+    Raises:
+        TypeError: If the data is not a dictionary or a list of dictionaries.
+    """
+    # check if the data is valid
+    if isinstance(data, dict):
+        new_data = {}  # new dictionary to store the data with periods replaced by underscores
+        logging.info("Converting periods to underscores in dictionary keys...")
+        for key, value in data.items():
+            new_key = key.replace('.', '_')
+            if isinstance(value, (dict, list)):
+                new_data[new_key] = replace_periods_in_keys(value)
+            else:
+                new_data[new_key] = value
+        logging.info("Dictionary keys converted successfully.")
+        return new_data
+
+    elif isinstance(data, list):  # if the data is a list
+        new_data = []
+        logging.info("Converting periods to underscores in list of dictionary keys...")
+        for item in data:
+            if isinstance(item, (dict, list)):
+                new_data.append(replace_periods_in_keys(item))
+            else:
+                new_data.append(item)
+        logging.info("List of dictionary keys converted successfully.")
+        return new_data
+
+    else:
+        raise TypeError("Data must be a dictionary or a list of dictionaries.")
